@@ -580,6 +580,7 @@ class Plan(HeadersMixin):
                             callback=test.get("callback"),
                             wait_for=build.uid,
                             command=test.get("commands", []),
+                            qemu_image=test.get("qemu_image"),
                         )
                     )
                 self.builds.append(build)
@@ -610,6 +611,7 @@ class Plan(HeadersMixin):
                             timeouts=test.get("timeouts"),
                             callback=test.get("callback"),
                             command=test.get("commands", []),
+                            qemu_image=test.get("qemu_image"),
                         )
                     )
 
@@ -900,6 +902,7 @@ class Test(HeadersMixin):
     timeouts = attrib(default=[])
     callback = attrib(default=None)
     command = attrib(default=[])
+    qemu_image = attrib(default=None)
 
     uid = attrib(default=None)
     wait_for = attrib(default=None)
@@ -942,6 +945,8 @@ class Test(HeadersMixin):
             data["callback"] = self.callback
         if self.command:
             data["command"] = self.command
+        if self.qemu_image:
+            data["qemu_image"] = self.qemu_image
         if plan is not None:
             data["plan"] = plan
 
