@@ -316,6 +316,7 @@ def handle_submit(cmdargs, _, config):
             wait_for=cmdargs.wait_for,
             callback=cmdargs.callback,
             command=cmdargs.commands,
+            qemu_image=cmdargs.qemu_image,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
@@ -478,6 +479,11 @@ def test_cmd_options(sp):
         help="Space separated list of commands to run inside the VM",
         default=[],
     )
+    sp.add_argument(
+        "--qemu-image",
+        default=None,
+        help="Use qemu from the given container image",
+    )
 
 
 def setup_parser(parser):
