@@ -332,3 +332,11 @@ def format_plan_result(build, tests):
         print(builds + tests_str)
     else:
         print(builds + tests_str)
+
+
+def get_remote_version(config):
+    ret = get(config, "/v1/versions")
+    if ret.status_code != 200:
+        error("Unable to fetch remote versions")
+    else:
+        return ret.json()
